@@ -7,21 +7,17 @@ module Program.Mighty (
   -- * State
   , module Program.Mighty.FileCache
   , module Program.Mighty.Report
-  , module Program.Mighty.State
   -- * Utilities
   , module Program.Mighty.ByteString
   , module Program.Mighty.Network
   , module Program.Mighty.Process
   , module Program.Mighty.Resource
   , module Program.Mighty.Signal
-  -- * Internal modules
-  , module Program.Mighty.IORef
   ) where
 
 import Program.Mighty.ByteString
 import Program.Mighty.Config
 import Program.Mighty.FileCache
-import Program.Mighty.IORef
 import Program.Mighty.Network
 import Program.Mighty.Parser
 import Program.Mighty.Process
@@ -29,4 +25,3 @@ import Program.Mighty.Report
 import Program.Mighty.Resource
 import Program.Mighty.Route
 import Program.Mighty.Signal
-import Program.Mighty.State
